==> SOAP-WSDL-2.00_07.tar.gz: SOAP-WSDL-2.00_07/example/lib/MyElements/GetCitiesByCountryResponse.pm <==
package MyElements::GetCitiesByCountryResponse;
use strict;
use Class::Std::Storable;
use SOAP::WSDL::XSD::Typelib::Element;

# atomic complexType
# <element name="GetCitiesByCountryResponse"><complexType> definition
use SOAP::WSDL::XSD::Typelib::ComplexType;
use base qw(
    SOAP::WSDL::XSD::Typelib::Element
    SOAP::WSDL::XSD::Typelib::ComplexType
);


my %GetCitiesByCountryResult_of :ATTR(:get<GetCitiesByCountryResult>);


__PACKAGE__->_factory(
    [ qw( 
    GetCitiesByCountryResult
    ) ],
    { 
       GetCitiesByCountryResult => \%GetCitiesByCountryResult_of, 
        
    },
    {
      
        GetCitiesByCountryResult => 'SOAP::WSDL::XSD::Typelib::Builtin::string',        
         
      
    }
);



sub get_xmlns { 'http://www.webserviceX.NET' }

__PACKAGE__->__set_name('GetCitiesByCountryResponse');
__PACKAGE__->__set_nillable();
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref('');

1;


__END__

=pod

=head1 NAME MyElements::GetCitiesByCountryResponse

=head1 SYNOPSIS

=head1 DESCRIPTION

Type class for the XML element GetCitiesByCountryResponse. 

=head1 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY 
methods:

 GetCitiesByCountryResult

=head1 Object structure

        GetCitiesByCountryResult => 'SOAP::WSDL::XSD::Typelib::Builtin::string',        
        

Structure as perl hash: 

 The object structure is displayed as hash below though this is not correct.
 Complex hash elements actually are objects of their corresponding classes 
 (look for classes of the same name in your typleib).
 new() will accept a hash structure like this, but transform it to a object 
 tree.

    'GetCitiesByCountryResponse'=> {
     'GetCitiesByCountryResult' => $someValue,
   },


=cut

==> SOAP-WSDL-2.00_15.tar.gz: SOAP-WSDL-2.00_15/example/lib/MyElements/GetCitiesByCountryResponse.pm <==
package MyElements::GetCitiesByCountryResponse;
use strict;
use Class::Std::Storable;
use SOAP::WSDL::XSD::Typelib::Element;


# atomic complexType
# <element name="GetCitiesByCountryResponse"><complexType> definition
use SOAP::WSDL::XSD::Typelib::ComplexType;
use base qw(
    SOAP::WSDL::XSD::Typelib::Element
    SOAP::WSDL::XSD::Typelib::ComplexType
);


my %GetCitiesByCountryResult_of :ATTR(:get<GetCitiesByCountryResult>);


__PACKAGE__->_factory(
    [ qw(
    GetCitiesByCountryResult
    ) ],
    { 
       GetCitiesByCountryResult => \%GetCitiesByCountryResult_of, 
        
    },
    {
      
        GetCitiesByCountryResult => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
        
      
    }
);



sub get_xmlns { 'http://www.webserviceX.NET' }

__PACKAGE__->__set_name('GetCitiesByCountryResponse');
__PACKAGE__->__set_nillable();
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref('');

1;


__END__






=pod

=head1 NAME 

MyElements::GetCitiesByCountryResponse

=head1 SYNOPSIS

=head1 DESCRIPTION

Type class for the XML element GetCitiesByCountryResponse. 

=head1 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY 
methods:

 GetCitiesByCountryResult

=head1 Object structure

        GetCitiesByCountryResult => 'SOAP::WSDL::XSD::Typelib::Builtin::string',        
        

Structure as perl hash: 

 The object structure is displayed as hash below though this is not correct.
 Complex hash elements actually are objects of their corresponding classes 
 (look for classes of the same name in your typleib).
 new() will accept a hash structure like this, but transform it to a object 
 tree.

    'GetCitiesByCountryResponse'=> {
     'GetCitiesByCountryResult' => $someValue,
   },


=cut
